@@ -19,6 +19,8 @@ skewsymmetry <- function(x)
       Svectors[,i]<-s$u[,i+1]
     }
 }
+  if(!is.null(rownames(x)))
+    rownames(Svectors)<-rownames(x)
 
   lk <- list(S = S, A = A, linear = lin, sv = Svectors, nobj = nobj)
   class(lk) <- "skewsymmetry"
